package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(`*``!````V9X``#0```#,L@```@``!30`(``)
M`"@`'0`<``$``'"@HP``H",!`*`C`0`(````"`````0````$````!@```#0`
M```T@```-(```"`!```@`0``!0````0````#````5`$``%2!``!4@0``$P``
M`!,````$`````0````$``````````(````"```"LHP``K*,```4`````@```
M`0```-2N``#4K@$`U*X!`)0"``#,$@``!@````"````"````X*X``."N`0#@
MK@$`(`$``"`!```&````!`````0```!H`0``:($``&B!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71DU*X`
M`-2N`0#4K@$`+`$``"P!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````"````!@```!`````$````%`````,```!'
M3E4`IL\61T3ZHDTZU&93`!"'K1=;9GYA````>P```"D```````````````X`
M````````4@```'``````````;0```",```!C````5````"$````&````7```
M```````V````9````'@````+````*P```!H```!T````!```````````````
M#P```$D````>```````````````]`````P```$P````7`````````'$````[
M`````````%``````````;@````````!H`````````!P````,````````````
M```X````90````````!G``````````````!'````.@````H```!W````````
M``````!+`````````!@``````````````"4`````````9@```"P````1````
M00```"<````P```````````````S````:0```#P```!5````30```$,```!S
M````60```%T````````````````````U````"``````````?````&0```"0`
M```O````:@```"8````````````````````W````40``````````````````
M`$``````````(``````````^````>@```"X`````````````````````````
M``````````!R``````````(```!B````6````#D```````````````````!U
M`````````#$``````````````$X````````````````````4````````````
M``!"`````````%,``````````````%H``````````````%L`````````````
M````````````%@```````````````0```#(```!V````$````!4```!7````
M``````4``````````````$@`````````(@```!(`````````7@```&L`````
M````/P```&````````````````D``````````````#0```!&````&P``````
M``!6````````````````````!P````````!?````80```'D```!*````$P``
M````````````*```````````````#0```&P````=````*@`````````M````
M``````````!$````3P``````````````10```````````````````&\`````
M``````````````!A`````P```"`````*````H!(`"`)&$:"````(5@!Q&,((
M`#P-`!41```0`@`H`````````%@B(`H$"@!$A`>H0`A%8$D`A`$^0CR7``$`
M""%0@"0)8`R!>$E$6B)``$```0!"&0!`@(S`A``"$)`0@PD`"`$0D(E`0,))
M@"Q`F`!``"``(`0)@)2![(Z7=L`#``````````0````%````!P````@`````
M```````````````)````"P````T````/`````````!`````2````%@``````
M```8`````````!D````:````'0```!X````B````(P```"0````F````````
M`"<````H````+``````````M````+@```"\````P````,0`````````S````
M`````#<````X`````````#P``````````````#T````_````0`````````!!
M````0@```$0```!(````2P````````!.````3P```%````!1````````````
M````````4P````````````````````````!5````5@````````!8````````
M`%H```!<````7@```%\```!@``````````````!A````90````````!G````
M`````&D`````````;````&X`````````<````'$```!R````=````'4```!X
M````7Y:3'*-:[Y!6VY,<PXZ'_PTZEPM'[#,ZTE$$A(%T@@UZ\$IK?4&.Q794
M/)3-/PRO]R/.(-1DU'PA=+`"X%)W*"Y./?9FK\QFV_<`7@:DA_\!KS3HL4B=
MYU-F(9K@IP(*SDJN_\_>1RWC1\8!;'.%Q>P_D`+&#N`]/WZ6?#5O3M[%B060
M8)CO$F=)22(!(_FDG;N3''SM$0^@DFAGAOF<@4-%U>Q;FCL/04V=?'&$,(0M
M5>O6I]VC:UCOEWFC`&6O#!3BGJ("]AG:S>.>!3*EA?NA;&`R8MOMZM/O#L@Y
M0!^YC?$.Z?O#PDHB??_MWI,<K4OCP-EQ6!PKT.$B+`ZQ<QN?UKU@%LE96#M`
M']I?22'#Y3\LF"+4:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(
MWH4@3YOH?!C>ZR(53UIHR<6YG$`PN((-41M]7[(!BV^_VE<;=F_C<+W02WUJ
M"4/6GR+'J"%B9`=3J0>0'0(047ZIG)MBT/J"["SVBVM_FGS0GRS\A_"6?.X+
M4?GSV],=YO\PHI!U@@U#9DL07E]V8`5LLLT6ZEKQ/:TY#2G\#:BCX/M)XE?$
M&%>26E+]TN\/+-_^2&[%WQ]]D!#I+L6;MLC5LG'?J\J?````````````````
M`````!$``````````````"`````@```````````````@````.`0``)R>````
M````$@````D#``!,G0```````!(```"@`P``^)P````````2````A`,``-"=
M````````$@```),%``!4L0$``````"``&`#2!0``8+$!``0````1`!@`>@(`
M`$B;````````$@```'T#``"$G@```````!(```!J`@``=)P````````2````
MM@4``"6M```R````$@`.`+8$``!HL0$``````!``\?\W`P``,)X````````2
M````8@,``+"<````````$@````8%``!UP```Y`(``!(`#@#5`P``-)T`````
M```2````L0````R;````````$@```#\$``!4FP```````!(```!`!0``T;,`
M`+`````2``X`2`,``!R=````````$@```.T#```(G````````!(```#%!```
MH,$!```````0`/'_4`$``/2=````````$@```(D$``"@(P$``````!``\?\J
M!0``Y:\``)P````2``X`7@4``,B<````````$@```.$%``#YMP``?`@``!(`
M#@#I!```69\``"@````2``X`P@,```">````````$@```$,"```\G@``````
M`!(```!O`P``2)X````````2````,@,``*B>````````$@```(`!``"0FP``
M`````!(```!2!```:+$!``0````A`!D`\0(``."<````````$@```-\#```H
MG0```````!(```#X`@``M)X````````2````D@,``*2<````````$@```'<#
M```PFP```````!(```"-`0``>)L````````2````H````("<````````$@``
M`*,$``!HL0$``````!``\?_K`@``!)T````````2````$0,``"R<````````
M$@```!T!```,G@```````!(```#^`0``Q)T````````2````4P0``&BQ`0`$
M````(0`9`-`$``"@P0$``````!``\?_L````B)T````````2````]@0``/G#
M```"````$@`.`!P"``"TFP```````!(```"F!0``_<,``$@````2``X`3@(`
M`!"=````````$@```.X%``#)L0``M````!(`#@"7!0``V9X````````2``X`
M``4``$7$````````$@`/`%$#``!DG0```````!(```"@!0``[9H````````2
M``P`UP```+B=````````$@```+0#``#DFP```````!(```"+`P``<)T`````
M```2````@@4``$S$```$````$0`0`*H$``!HL0$``````!``\?\1!```&)X`
M```````2````-````&B<````````$@```"D$``"@G0```````!(```!S!0``
M9+$!``0````1`!@`70$``(R<````````$@```)<$``"H(P$``````!``\?^>
M!0``6<,``"P````2``X`H0$``"2;````````$@```)X$``"@P0$``````!``
M\?\`!@``C;8``&P!```2``X`_0```*B;````````$@```"`#``"LG0``````
M`!(```!X````P)X````````2````UP(``#B<````````$@```%P"``#LG```
M`````!(````+`0``S)X````````2````00$``-2<````````$@```&,```!X
MG@```````!(```#J`0``_)L````````2````0@```)2=````````$@```%$$
M``!HL0$`!````!$`&0"9`P``P)L````````2````R@$``,R;````````$@``
M`!P%```)K```-````!(`#@#$!```H,$!```````0`/'_S0,``#R;````````
M$@```,@```"8G````````!(```"1!0``5+$!```````0`!@`&P0``"2>````
M````$@```&D$``!PL0$`!````!$`&0!N`0``A)L````````2````CP```)">
M````````$@```$P%``#!LP``$````!(`#@"8`@``\)L````````2````A0(`
M`-R=````````$@```$P$``#5M```N`$``!(`#@#]`P``V)L````````2````
MI@$``""<````````$@```/0#``#HG0```````!(```"C`@``>+$!`!,````1
M`!D`UP4``+S'``#:6P``$0`0`*T#``"\G````````!(```"G`P``?)T`````
M```2````+P$``%"<````````$@```#\#``!LG@```````!(````Q!```1)P`
M```````2````D0(``%B=````````$@```-@!``!@G@```````!(````-!@``
M?;(``$0!```2``X`!`0``%R<````````$@```*L!``!`G0```````!(```!I
M`P``&)L````````2````+`(``)R;````````$@```&<%``"!M```5````!(`
M#@!4````5)X````````2````V`0``(&P```(````$@`.`+<!``!@FP``````
M`!(````U`@``%)P````````2`````&QI8G!E<FPN<V\N-2XQ,`!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R
M;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F;&%G
M<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?<'1R
M`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P97)L
M7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP87)S97)?
M<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])=&]P
M7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S=E]S971P=FX`4&5R
M;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P='(`
M4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F<F5E`%!E
M<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E
M<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])<&5R
M;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N
M`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?
M879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N
M,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF
M:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D
M`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S
M=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`
M<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M
M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A
M=#8T`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E
M861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<F5A9&1I<C8T`%]?<W!R:6YT
M9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN
M`%]?96YV:7)O;@!L9"UL:6YU>"YS;RXS`%]?<W1A8VM?8VAK7V=U87)D`&QI
M8F-R>7!T+G-O+C$`7U]E>&ED>%]S=&%R=`!?7V5X:61X7V5N9`!?961A=&$`
M7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?
M`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN
M:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``<VEZ95]L;V%D7VUE7S(`7TE/7W-T9&EN
M7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!N86UE7VQO861?;65?,@!P87)?
M;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I
M;FET7V5N=@!'3$E"0U\R+C0``````````@`#``(``@`!``$````"`````0`!
M``(``@`!``(````"``$``@`"``$````!``$``@`!``$``@````(``@````(`
M`P`"``,``@`"```````!``,``P```````@`!`````0````$````!``$``0`"
M``$````"``(``0`!``(````"``$````!``$````!``$````"`````P``````
M```````````"``(````!``$``@````$``@`$```````!```````!``(``@`"
M`````0`"``(````"``(``@````$``@````(````!`````0`````````!``$`
M6P0``!`````@````%&EI#0``!``:!@````````$``0#'`@``$````"`````4
M:6D-```#`!H&`````````0`!`!8#```0`````````!1I:0T```(`&@8`````
M``!0L0$`%0$``&BQ`0`450``<+$!`!1>``!XL0$`%&@```RP`0`6$@``$+`!
M`!9T```4L`$`%D@``!BP`0`6*```'+`!`!9:```@L`$`%@D``"2P`0`6$P``
M*+`!`!9Y```LL`$`%@$``#"P`0`6*0``-+`!`!9?```XL`$`%B(``#RP`0`6
M=0``0+`!`!9+``!$L`$`%C0``$BP`0`65@``3+`!`!97``!0L`$`%F4``%2P
M`0`6/0``6+`!`!9B``!<L`$`%E,``&"P`0`6%@``9+`!`!9Z``!HL`$`%F8`
M`&RP`0`6+0``<+`!`!9.``!TL`$`%FX``'BP`0`6;```?+`!`!9R``"`L`$`
M%D(``(2P`0`6"P``B+`!`!8J``",L`$`%D4``)"P`0`66P``E+`!`!8G``"8
ML`$`%@\``)RP`0`6:@``H+`!`!8;``"DL`$`%E$``*BP`0`6)```K+`!`!9/
M``"PL`$`%@4``+2P`0`6+```N+`!`!8V``"\L`$`%A4``,"P`0`6)0``Q+`!
M`!81``#(L`$`%G,``,RP`0`6!```T+`!`!9O``#4L`$`%CH``-BP`0`6/@``
MW+`!`!9K``#@L`$`%C(``.2P`0`65```Z+`!`!9#``#LL`$`%DP``/"P`0`6
M/```]+`!`!8O``#XL`$`%@8``/RP`0`68P```+$!`!9G```$L0$`%A@```BQ
M`0`6'@``#+$!`!8N```0L0$`%D$``!2Q`0`670``&+$!`!8.```<L0$`%A\`
M`""Q`0`6(```)+$!`!9W```HL0$`%G```"RQ`0`6;0``,+$!`!92```TL0$`
M%@H``#BQ`0`68```/+$!`!8#``!`L0$`%B$``$2Q`0`6)@``2+$!`!9-``!,
ML0$`%E```!"U`/`/^@"_$+T```3@+>4$X)_E#N"/X`CPON7X%`$``,:/XA'*
MC.+X]+SE`,:/XA'*C.+P]+SE`,:/XA'*C.+H]+SE`,:/XA'*C.+@]+SE`,:/
MXA'*C.+8]+SE`,:/XA'*C.+0]+SE`,:/XA'*C.+(]+SE`,:/XA'*C.+`]+SE
M`,:/XA'*C.*X]+SE`,:/XA'*C.*P]+SE`,:/XA'*C.*H]+SE`,:/XA'*C.*@
M]+SE`,:/XA'*C.*8]+SE`,:/XA'*C.*0]+SE`,:/XA'*C.*(]+SE`,:/XA'*
MC.*`]+SE`,:/XA'*C.)X]+SE`,:/XA'*C.)P]+SE`,:/XA'*C.)H]+SE`,:/
MXA'*C.)@]+SE`,:/XA'*C.)8]+SE`,:/XA'*C.)0]+SE`,:/XA'*C.)(]+SE
M`,:/XA'*C.)`]+SE`,:/XA'*C.(X]+SE`,:/XA'*C.(P]+SE`,:/XA'*C.(H
M]+SE`,:/XA'*C.(@]+SE`,:/XA'*C.(8]+SE`,:/XA'*C.(0]+SE`,:/XA'*
MC.((]+SE`,:/XA'*C.(`]+SE`,:/XA'*C.+X\[SE`,:/XA'*C.+P\[SE`,:/
MXA'*C.+H\[SE`,:/XA'*C.+@\[SE`,:/XA'*C.+8\[SE`,:/XA'*C.+0\[SE
M`,:/XA'*C.+(\[SE`,:/XA'*C.+`\[SE`,:/XA'*C.*X\[SE`,:/XA'*C.*P
M\[SE`,:/XA'*C.*H\[SE`,:/XA'*C.*@\[SE`,:/XA'*C.*8\[SE`,:/XA'*
MC.*0\[SE`,:/XA'*C.*(\[SE`,:/XA'*C.*`\[SE`,:/XA'*C.)X\[SE`,:/
MXA'*C.)P\[SE`,:/XA'*C.)H\[SE`,:/XA'*C.)@\[SE`,:/XA'*C.)8\[SE
M`,:/XA'*C.)0\[SE`,:/XA'*C.)(\[SE`,:/XA'*C.)`\[SE`,:/XA'*C.(X
M\[SE`,:/XA'*C.(P\[SE`,:/XA'*C.(H\[SE`,:/XA'*C.(@\[SE`,:/XA'*
MC.(8\[SE`,:/XA'*C.(0\[SE`,:/XA'*C.((\[SE`,:/XA'*C.(`\[SE`,:/
MXA'*C.+X\KSE`,:/XA'*C.+P\KSE`,:/XA'*C.+H\KSE`,:/XA'*C.+@\KSE
M`,:/XA'*C.+8\KSE`,:/XA'*C.+0\KSE`,:/XA'*C.+(\KSE`,:/XA'*C.+`
M\KSE`,:/XA'*C.*X\KSE`,:/XA'*C.*P\KSE`,:/XA'*C.*H\KSE`,:/XA'*
MC.*@\KSE`,:/XA'*C.*8\KSE`,:/XA'*C.*0\KSE`,:/XA'*C.*(\KSE`,:/
MXA'*C.*`\KSE`,:/XA'*C.)X\KSE3_``"T_P``Y=^`0;:D9-^`0M3?@$#=_X
M%,!-^`3-!$@$2__W+.[_]QCN``#YPP``U;0``/W#```%2P"_`*(0M9L8!$J;
M6`NQ__<D[A"]`+_H$`$`4`$```)+&G@*N0$B&G!P1XNQ`0`#2!"U`V@3L0)+
M`[&81Q"]W*X!```````#>&NQ`49"'`9(`&@`>(-""+\11A+X`3L`*_C1"$9P
M1P%&^^=0Q```+>GP#]"P`"(`\1P%:T:I6`P&3^H!+$3J$60,]'\,"0I$Z@P,
M`?1_04SJ`0&94`0R0"KLT0/UFG0T,U/X%!P::%/X+,R!Z@("4_@T'(+J#`)*
M0$_J\G+:8`0SHT+MT4_VP&)0K,_V_W+0^!"`16A']ID6H5C%]H(F,D;0^`B@
M0430^`R`CAD!:$_JM0<HZ@4%T/@$@"KJ`0P&Z_%F`9P*Z@@!T/@`@-#X#*`-
M0P?J"`%U&51$3.H!`:(8T/@(H-WX",!2&$?VF1$"Z_5D3^JX!M1$W?@,@,7V
M@B$GZ@4*"D9A1`7J!@Q/ZK4%`>OT84KJ#`Q"1";J!`H$Z@4(C$32&4KJ"`C=
M^!"01_:9$4)$Q?:"(0+K_&=/ZK0$W?@4@$E$1_:9$B7J#`J)&<7V@B(,Z@0&
M3^J\#"3J!PD!Z_=A2NH&"D)$!^H,"`'K"@92&4GJ"`C=^!B@1_:9$4)$Q?:"
M(0+K]F5/ZK<'W?@<@%%$1_:9$BSJ!@H)&<7V@B(&Z@<$3^JV!B?J!0D!Z_5A
M2NH$"D)$!>H&"`'K"@1)Z@@(W?@@H&)$1_:9$4)$Q?:"(0+K]&Q/ZK4%W?@D
M@%%$1_:9$B;J!`K)&<7V@B($Z@4'3^JT!"7J#`D!Z_QA2NH'"D)$#.H$"`'K
M"@>2&4GJ"`C=^"B@1_:9$4)$Q?:"(0+K]V9/ZKP,W?@L@%%$1_:9$B3J!PI)
M&<7V@B('Z@P%3^JW!RSJ!@D!Z_9A2NH%"D)$!NH'"`'K"@42&4GJ"`C=^#"@
M1_:9$4)$Q?:"(0+K]61/ZK8&W?@T@%%$1_:9$B?J!0IA1,7V@B(%Z@8,3^JU
M!2;J!`D!Z_1A2NH,"D)$!.H%"`'K"@S2&4GJ"`@.GT?VF1%"1,7V@B$"Z_QJ
M3^JT!'D81_:9$@^?)>H,"(D9Q?:"(@SJ!`9/ZKP,).H*";H8`>OZ80KJ#`=(
MZ@8(`>L(!E(92>H'!]WX0(!']ID1TAG%]H(A`NOV94_JN@H1GT%$1_:9$BSJ
M!@@)&<7V@B(&Z@H$NAA/ZK8&`>OU84CJ!`@!ZP@$*NH%"07J!@<2F91$1_:9
M$DGJ!P?%]H(B3^JU!8H8O$1']ID1$Y\,Z_1L)NH$"%)$Q?:"(03J!0I/ZK0$
M>1A(Z@H*#.H$!R7J#`@"Z_QIB1G=^%"P2.H'!D[VH3+*1$_JO`R.&16?QO;9
M8D[VH3&,Z@0(6D3&]MEA!NOZ9E(9>1B(Z@H%3^JZ"@D951D6GXKJ#`1.]J$R
M3^JV"'1`QO;98@7K]F4!ZP0)NA@7G(CJ"@9.]J$Q;D!B1,;VV6$)Z_5LEQE/
MZK4%81A.]J$R&)Q11(7J"`I/ZKP&!^O\9\;VV6**Z@P,ANH%":(8W?ADH(Q$
M3O:A,0SK]VQ"1(GJ!P3&]MEA3^JW!Q09W?AH@%%$3O:A,H?J!@I)&03K_&1/
MZKP%QO;98HKJ#`Q"1(7J!PK=^&R`C$1.]J$QDAD,Z_1LBNH$!L;VV6%/ZK0$
MEAF$Z@4*041.]J$RW?AP@,D9!NO\9D_JO`?&]MEBBNH,#$)$A^H$"MWX=(",
M1$[VH3%2&0SK]FR*Z@8%QO;984_JM@95&8;J!PI!1$[VH3+=^'B`"1D%Z_QE
M3^J\!,;VV6**Z@P,0D2$Z@8*W?A\@(Q$3O:A,=(9#.OU;$_JM0?&]MEABNH%
M!4%$A^H$"E49W?B`@$[VH3*)&07K_&5/ZKP&QO;98HKJ#`Q"1(;J!PK=^(2`
MC$1.]J$Q$AD,Z_5L3^JU!,;VV6&*Z@4%042$Z@8*51G=^(B`3O:A,LD9!>O\
M94_JO`?&]MEBBNH,#$)$A^H$"MWXC(",1$[VH3&2&0SK]6Q/ZK4&QO;988KJ
M!05!1(;J!PI5&=WXD(!.]J$R"1D%Z_QE3^J\!,;VV6**Z@P,A.H&"=WXE*",
M1$)$3O:A,4_JM0C2&0SK]6S&]MEAB>H%!5%$B.H$"549W?B8H$[VH3)/ZKP'
M!>O\98D9B>H,#,;VV6*'Z@@&4D1A1`'K]6P4&6Y`)YE.]J$R3^JU!:89QO;9
M8@;K_&:%Z@<)BAC=^*"@3^J\`4OVW$2)Z@P,0D1!Z@4)R/8;=`+K#`@)Z@8)
M3^JV`MWXI+!41$OVW$P!Z@4*Y!D(Z_9F0NH!!TGJ"@K(]AM\HD0W0`+J`03<
M1*Q$)T,JG4_JM@1+]MQ("NOV9D3J`@EG1,CV&WA/ZK8,!^OV9P3J`@JH1`GJ
M!@DKG4OVW$9!1,CV&W9)Z@H(3.H$":X9B$0)Z@<)3^JW`=WXL+`,Z@0*2_;<
M10CK]V>R&$GJ"@I!Z@P&R/8;=3Y``>H,"%)$740L&4;J"`HMG4_JMP8"Z_=H
M2_;<0@3K"@=&Z@$+R/8;<D_JN`2J&`?K^&<&Z@$)W?BXH`OJ"`M+]MQ%8D1+
MZ@D(R/8;=43J!@F01%5$3^JW`@GJ!PG=^+RP!.H&"DOVW$P(Z_=G:1A)Z@H*
M0NH$!<CV&WP]0`+J!`A11-Q$1>H("K1$3^JW!0'K]V@PGDOVW$$,ZPH'1>H"
M"\CV&W%/ZK@,!^OX9P7J`@EQ&-WXQ*`+Z@@+2_;<1@D92^H)",CV&W9,Z@4)
MB$161$_JMP$)Z@<)W?C(L`SJ!0I+]MQ$".OW9[(82>H*"D'J#`;(]AMT/D`!
MZ@P(4D1<1&091NH("C.=3^JW!@+K]VA+]MQ"!.L*!T;J`0O(]AMR3^JX!`?K
M^&<&Z@$)JAC=^-"@"^H("TOVW$5B1$OJ"0C(]AMU1.H&"9!$541/ZK<"">H'
M"=WXU+`$Z@8*2_;<3`CK]V=I&$GJ"@I"Z@0%R/8;?#U``NH$"%%$W$1%Z@@*
MM$1/ZK<%`>OW:#:>2_;<00SK"@=%Z@(+R/8;<4_JN`P'Z_AG!>H""7$8W?C<
MH`OJ"`M+]MQ&"1E+Z@D(R/8;=DSJ!0F(1%9$3^JW`0SJ!0K=^."P">H'"4OV
MW$0(Z_=GLAA)Z@H)0>H,!LCV&W0^0`'J#`A*1%Q$`NOW:D;J"`ED&4_JMP8Y
MFDOVW$A,1,CV&WA&Z@$)!.OZ9Y!$">H*"4_JN@(ZG0;J`0I+]MQ$Q$3(]AMT
M2>H*"$+J!@DL&>!$3^JW!0GJ!PD"Z@8*W?CLL$OVW$QA&`CK]V=)Z@H*R/8;
M?$7J`@D!ZPH(">H'"3R<!>H""MQ$3/+6$0CK]VBT1$_JMP=)Z@H*S/9B(8?J
M!09A&.)$/9Q,\M8<3^JX"0KK^&J*&(;J"`;,]F(LDAFD1(GJ!P8^G$SRUA%/
MZKH(`NOZ8H;J"@:L1,SV8B$_G6$8M$1,\M84B.H)!D_JL@H,Z_)LR1F&Z@("
MS/9B)(KJ"`:)&"P93/+6$D"=3^J\!P'K_&%,1(;J#`S,]F(BA^H*!JH89$1!
MG4SRUAQ/ZK$)!.OQ9$)$ANH!`<SV8BR)Z@<&4ABL1$SRUA%"G4_JM`@"Z_1B
MU$2&Z@0$S/9B(8CJ"09I&*1$0YU,\M843^JR"@SK\FS)&8;J`@+,]F(DBNH(
M!HD8+!E,\M821)U/ZKP'`>O\84Q$ANH,#,SV8B*'Z@H&JAAD1$6=3/+6'$_J
ML0D$Z_%D0D2&Z@$!S/9B+(GJ!P92&*Q$3/+6$4:=3^JT"`+K]&+41(;J!`3,
M]F(AB.H)!FD8I$1'G4SRUA1/ZK(*#.OR;,D9ANH"`LSV8B2*Z@@&B1@L&4SR
MUA)(G4_JO`<!Z_QA3$2&Z@P,S/9B(H?J"@9D1*H83/+6'$F=3^JQ"03K\61"
M1(;J`0',]F(LB>H'!E(8K$1,\M812IU/ZK0(`NOT8M1$ANH$!,SV8B&(Z@D&
MI$1I&$SRUA1+G4_JL@H,Z_)LR1F&Z@("S/9B)(KJ"`:)&"P93/+6$DR=`>O\
M84_JO`=,1(;J#`S,]F(BA^H*!F1$JAA,\M8<39T$Z_%D3^JQ"4)$ANH!`<SV
M8BQ2&*Q$B>H'!DZ=3/+6$0+K]&)/ZK0(U$2&Z@0$3YO,]F(A!FBD1&D83/+6
M%(CJ"04,Z_)L\QC)&4_JL@;,]F(DA>H"`M#X!*"*&!P9ANH(`P+K_&),1(/J
M#`/C&`KK`@&$:`/K\F/%:-#X$*`$Z[P,`V"N&=!$06#`^!"`P/@(P,9@4+"]
MZ/`/<$<MZ?!'!4:*1A"Y`""]Z/"''$O3^`"`N/$`#_;0`W@?'AB_`2<]*PR_
M`"<'\`$';[$'1A?X`3\:'AB_`2(]*PR_`","\`$#`"OST7\;V/@`0``LVM!&
M1B!&*48Z1O_W,.D0N>-=/2L$T%;X!$\`+/+1R^?(ZP8&>!P@&+80RO@`8,3G
M`+]HL0$``+6#L`&I__>W_P.P`+T`OQ"U"DP@:+#Q_S\`T!"]"$C_]^[_,+$`
M>""Q,#@8OP$@(&#SYP`@(&#PYP"_7+$!`,C$``!PM8*P!48!K`E.">`!FC-H
M`^N"`U/X!"]#^`0L`"KYT2A&(4;_]X;_`"COT0*P<+UHL0$`+>GP02E,K?6`
M70]&@K"01B-H`JT-]8!<!#T,\00,)$@I1D#V_W+,^``P__>FZ``H!D8MW4,>
MZESZL0*M+R$$/3)&*$;_]^;H`"@AT``@__?0Z`!H_O>X[SE&*D8S1O_W`N@-
M]8!3!#,::"-HFD(:T0*P#?6`7;WH\(%+L0*M'D8$/2\A,D8H1O_WQ.@`*-W1
M`"#_]Z[H`&C^]Y;O.49"1O[W7._=Y__W)N@`OW"Q`0#4Q```$+4`(/_WFN@`
M:/[WA.]/\/\Q_O=N[P`@__>0Z`!H_O=Z[TKV65'`\@`!`"+_][;H$+T`OQ"U
M`"#_]X#H`&C^]VKO_O?2[@-&`"`;:%QH__=VZ`!H_O=>[_[W`N\#1@`@&W@C
M=O_W:N@`:/[W5._^][SN`T8`(!MH7&C_]V#H`&C^]TCO_O?R[@-&`"`;:!N*
MP_,(`V.#__=2Z`!H_O<Z[_[WHNX#1@`@&VA<:/_W1N@`:/[W,.\`(C1)__<*
MZ.!A`"#_]SSH`&C^]R3O_O>,[@-&`"`;:%QH__<PZ`!H_O<:[_[WN.X#1@`@
M&V@C8O_W)N@`:/[W#N_^]W;N`T8`(!MH7&C_]QKH`&C^]P3O_O>J[P-H2[$`
M(/_W$.@`:/[W^N[^]Z#O`VC;;F-B`"#_]P;H`"0`:/[W[N[^]U;N`T8@1AMH
M6VB<8O[W^.\`:/[WXN[^]TKN`T8@1AMH6VC<8O[W[.\`:/[WUN[^]S[N`T8@
M1AMH7&C^]^+O`&C^]\KN_O>R[P-H(V,0O0"_!,8``"WI\$$$1IRP"+$#>!.Y
M'+"]Z/"!_O<X[@9&`"CWT`WQ"`@P1O[WGN\%1B!&`"TQT.M\$S4N*S30_O?:
M[@=&*$;^]];N.!@",/[W+.\!(1M+3_#_,@&5`)0'1O[WBN\#(#E&0D;^]PSO
ML/'_/P70!IL#]'!#L_6`3QS0.$;^][[N.$;^]W3N,$;^]VSO!48@1@`MS=$P
M1O[WZ.X@1O[W%.^UYVMX`"N\T"XKQ=&K>``KM]#!YSA&__>C_^'GY,0``'"U
M!$8`(/[W<N\`:/[W6N[^]P;O(48"1@,@_O<X[P5&"+$`('"]_O=B[P!H_O=*
M[O[W]NX#:0/T<$.S]8!/#=`H1O[W5.\`:/[W/.[^]^CN`VD#]'!#L_4@3^+1
M($8"(?[W-N[0\0$`.+\`(-KG`+_PM2--K?4`78>P*V@-]0!2%#(-]8!4&#03
M8`@\_O?F[@$A0?(!`AM+A$;-^`#`W_AHP"!&S?@$P/[W`N\`*`S:`"0-]0!3
M($84,QIH*VB:0AO1![`-]0!=\+T&KB!&##Y/](!2,4;^]\[N`"@'1N?;`3#^
M]X#N!$8`*.+0,48Z1O[W*NX`(^-5V^?^]WKN`+]PL0$`[,0``/C$```0M?_W
MK_\0O2WI\$4+>`Q&A;`]*P9&"+],'"!&_O<"[@.I!T8P1O_W8_T%1FBQ_O?Z
M[8=">M@`(^)<ZE0!,P`J^M$`(`6PO>CPA=_X](#8^````V@`*W#0`350^"4P
M`"OZT:D<B0`W2QIH0K'^]ZSN`T;(^```L+E/\/\PXN<!(@A&&F#^]RCN`T8`
M*/303^J%"MCX`!!21@&3_O="[@&;R/@`,`'@3^J%"FH<`"%#^"(0`Y4S>!H>
M&+\!(CTK#+\`(P+P`0-KL3)&$O@!/QD>&+\!(3TK#+\`(P'P`0,`*_/1DQNX
M'-CX`%#`&/[W].U%^`H``"B_T!%+`YD::#-X4O@A(!-P*[D&X'-X`38"^`$_
M"[$]*_C1`",](1%PX5S0&`$S07``*?G1BN?=^`R@W_@,@$_JB@J\YQU&""&2
MYVBQ`0",L0$`W_BHP"WI\$<,\00$!D:*L`_,!*TO1@_'E.@#``2<A^@#`"-X
M\['<^!R`!N#^]X#MV+%5^`1/(WBCL2!&__?X_#%&@D:Z\0`/`]":^``P`"OL
MT2!&,4;_]S/_5?@$3R-X`"OJT0JPO>CPAS!&_O<V[8%&0$;^]S+M!T901O[W
M+NU/1`(W.!C^]X3M`2%/\/\R!TO-^`B@`);-^`2`!T;^]][M($8Y1O_W"__"
MYU#$``#\Q```,+7?^.C`.DV+L&Q&O.@/`-7X`.#-^"3@[D:NZ`\`O.@/`*[H
M#P"\^`#`,DBN^`#`__?&_#!(__?#_#!(__?`_"](__>]_"](__>Z_"Y(__>W
M_"Y(__>T_"U(__>Q_"U(__>N_"Q(__>K_"Q(__>H_"M(__>E_"M(__>B_"I(
M__=]_`%&$+$C2/_WP/XG2/_W=?P!1A"Q)DC_][C^)4C_]VW\`49@L1E(__>P
M_A5((DG_]ZS^"9HK:)I"%=$+L#"]'DC_]UO\`488L1%(__>>_NSG!/$1`!I)
M"B+^]VSM`"CDT03Q&P'PY_[W_NQPQ```<+$!``3%```0Q0``&,4``"3%```L
MQ0``/,4``$C%``#(Q```5,4``&#%``!LQ0``?,4``(C%``"4Q0``J,4``+S%
M``#(Q0``^,4``-C%``#LQ0``$+7^]R+L_O>`[`"Q`&@0O1"U!$8@LP-X$[/^
M]V3L`3@C&)Q"*+_?^(S`#M+?^(3`(%S<^``@$7B(0@/0'.`:>()"&=$!.YQ"
M^=.C0AG1W/@``!IX`WB:0@+0_O<H[0?@`B#^]YKL&+$320(B_O=&[!"]&GB*
M0NC0`3N<0OG3HT+ET-SX```!.YQ"`](9>`)XD4+XT!L;FARR]8!?`=D`(.;G
M6APA1@5(3_2`4_[WNNL"2-WG4,0``/S%``"0L0$`<+4%1O_WI/\#>,.Q#TH$
M1@$P$F@2>)-""+\$1A#X`3L`*_C1__>P^T"Q/;$K>"NQ($8'2?[W(.R@0@+0
M<+T$1O#G*$;_]_;\^.<`OU#$````Q@``<+6&L(9&"T8#D@6H!*D#JLWX%.`$
MD_[WM.Q<25Q("D8`\&S_`"#^]X#K!'B4N?[W=NM82T/X]`P`*`#PF8#^]\+K
M($;^]Z+L`&C^]XSK_O=0[`1P`"#^]YKL`&C^]X+K_O>@[`-&`"`:>$+P`@(:
M</[WC.P`:/[W=NO^]Y3L`WA#\`$#`W`%F`4P!^Z0"KCN9VN?[3I[-NX':Y_M
M.GNT[L=K\>X0^E_<@``Z3/[W+.P$F]WX%.!$^/`,A$8::`)@-4I"8#5*@F`U
M2L)@!"*^\0$/1/CL+`C=`48!(E/X(@`!,@AA!#&61?C<#O$##E3X]`QR1F-&
M*TD`)0"53/@N4/[WN.H%1HBQ5/CT#/[WENLE2"!.__<&^\"Q5/CT#/[WF.K^
M]SCK*$8&L'"]&4L93E/X]`S^]\CJ!494^/0,_O=^ZQE(__?N^@`HYM%6^.@,
M$+'_]RO_X.<42/_WX_I&^.@,`"C9T/3G$4@22?[WNNL!,/[W,.P`OZ_S`(``
M````````````@/___\]!8)L``("<``"$P@$`",8``+S'```,Q@``A<,``#S%
M``!(Q0``.,8``'BQ`0`MZ?!/#49+\G`1K?6`7<#R`0&)L`WU@%*`1@MH'#).
M2-_X.*$38/_WH?K:^`!`(48'1D!&_O<:ZP9&H+%(2$%&__?<_`WU@%-+\G`1
M'#/`\@$!0$8::`MHFD)[T0FP#?6`7;WH\(]`1O[WUNK:^!RP648#1BA&!)/^
M]S3K!)L%1@`HV]`-\2`*W_C8D*KQ!`H!,P63*W@`*PB_348OL3A&*4;^][;K
M`"@^T"A&_O>TZB)X*Q@3^`$<D4((T0/X`6P!.!/X`BP!.R%XD4+VT`6;0/;_
M<1@8B$*PW`$A3_2`4B%+4$8`E0&4S?@(@/[W5.L`(/[W<.L`:/[W6.K^]P3K
M448"1@,@_O?0ZF"Y_O=BZP!H_O=,ZO[W^.H#:0/T<$.S]0!/!]``(%E&_O?<
MZ@5&`"BOT8+G4$8!(?[W/NH`*/'1448&2/_W6?Q01O[W2.N`1G?G_O?`ZDC%
M``!0Q```;,4``/S%``#\Q```+>GP3]_X.(A+\G`5K?4`30CQ1`/`\@$%@D;!
ML`_++FA`K`WU`$G`/`CQ5`P)\?P)#?6`?J[QV`X(\6P'R?@`8$"MA.@/`+`]
MO.@/`*[H#P"<Z`,`CN@#`)?H!P"%Z`<`W_C@!__WS/D$1ABQ`W@`*T#P1H/_
M]ZC]!T8`*`#P2H,\>'2Q_O=4ZCM&7R$":#+X%"`2\`@/"+\9<!/X`4\`+/31
M1_8H<PWU`4[/]O]S0*[8/E[X`P`#>#.YS>)6^`0/`W@`*P#PR(+_]YKY!$8`
M*/30__=3^P`H\-`@1O[WRNH`*.O0!48H1O[WX.D$1CA&_O?<Z288!O6`9@0V
M,$;^]S#J!$8P1@B4_O<JZM_X.,=/\/\RV/@`L`$AW_@P-\WX",``E0.7S?@$
ML`9&_O=^ZC!&0/+M$?[W].C?^!0'__=?^0`H`/#C@MKX`%#^]Y+J`48H1O_W
MGOX%1@`H`/#7@BA&_O>DZ0,H!T81W00XW_CD%B@8_O>6ZE"Y!"\`\(F"[QF;
M^``P%_@%+)I"`/"!@B]&__<]^0%&`"A7T-_XN!8`)=_XN`;_]W/[W_BT=O[W
M%.H!(4_P_S+?^*@V`);-^`2P`Y>$1B!&S?@(P/[W+NH4X/[W=.H#:!$K&-'^
M]_SI`2%"1M_X@#8!-0"6S?@$L`.5!)<"D"!&_O<8ZB!&0/+M$?[WCNBP\?\_
M@$;AT#!&_O<*Z=_X+`8A1O_W.?L@1O_WUOL-]0!,2_)P$0SQ_`S`\@$!")C<
M^``@"VB:0D#P_()!L`WU`$V]Z/"/.$;^]TSI!Y``**'00*U/\/\S;_`1`J0]
M1_9<=T_P`@C-^`"`_O=PZ0>8*48&(L_V_W?^]]KH#?4!0,-=&[EK>$,K`/"R
M@@WU`$H`(@`C"O%<"@>8`"4`E?[W5NE"\@$\#?4`3L;R17P.\60.RO@`P`WU
M`$Q`J0SQ8`P&D4WV_D')]KH!2O:),`WU`$G.^``0#?4`00GQN`G.]LUP#?4`
M1\SX``!L,0WU`$`-]0!*"O%T"EPW3O+P$V@PS/+2,T7R=D+)^`!0!_$<"0M@
M#?4`0\WX))`-]0!)P?(R`G`S`F`)\7@)!IK*^`!0HD:D.AU@!I('F$_T`$(&
MF?[W=N@`*`1&3]T-]0!,#/%P#-SX`"`"Z\0#FD(`\L>!#?4`3@[Q=`[>^``@
M#?4`00WU`$6X,0WU`$QP-0SQ=`P(:`+K5'(K8,SX`"``*$#PD8'=^!B`/RP4
MW0`E".L%`4`B2$9`-?[WBN@X1O[WZ?EC&S\K\MQ`/*,)6AR;`0CK@ACD&B)&
M1"-!1@F8_O=(Z`WU`$*X,@>8!ID48$_T`$+^]R;H`"@$1J_<!YA41O[WBN@-
M]0!#<#,-]0%*#?4`26_P?P$=:`GQ=`G%\\4#V?@`@`KK`P(!,S@K`OB('`#S
MD($'\1P`P_$X`L`8`"']]\CO2/*S#$CRL0+`\@`,#?4`0<#R``*P,6I$[$1(
M\K<.2/*U"HSX`(!/ZAACP/(`#@MP#?4`24_J&$/`\@`*$W`-]0!,#?4`0^Y$
M#/&V#+(S"?&T">I$.$:.^`!03^H8*(/X`(`K#HGX`#`K#"T*BO@`,(SX`%`-
M]0!%_O=J^0WU`$`-]0!!#?4`0EPP8#%D,F@UT/@`X`WU`$H(:`KQ;`H1:``C
M*FA(\NL%P/(`!0:3;43:^``P3^H>2D_J'FR%^`#@2/+O!<#R``5/ZAXN;40-
M]0!(#?4`20CQZ`@H<$CRZ07`\@`%"?&\"6U$3T:(^`#`A?@`H`WU`$7J-4_J
M$&J%^`#@#?4`1>PU3^H03@`*A?@`H$CR[0H-]0!%P/(`"NXUZD0H<$CR\06*
M^`#@P/(`!0WU`$IM1`KQ\`I/ZA%N"`PH<(KX`.!(\O,%#?4`2L#R``4*\?(*
M;41/ZA$N$`Z*^`#@#?4`2BEP"O'T"DCR]05/ZA).P/(`!8KX``!M1`WU`$H*
M\?8*$0J%^`#@2/+W!8KX`!#`\@`%#?4`2FU$"O'X"A@.*G!(\OL%BO@``$CR
M^0#`\@``#?4`0L#R``5H1&U$^C)/ZA-.&0HK<``E@/@`X!%P`>`8^`7`.$8!
M(0$U3_#_,I-+`C?-^`#`_O<"Z!0M\-$-]0!*S?@$L`KQY`H`(XKX`##-^`B0
MATL@1@$A3_#_,@"6`Y.'2_WW[._:Y4?V0',-]0%"S_;_<T"NP#[46"5X-;DZ
MY5;X!$\C>``K/_0TK2!&__=]^``H]-`@1OWW].\`*._0*.7:^`1P`"\_]'JM
M.$;]]P;O`RA_]G2M!#AR23@8_??Z[P`H/_1MK6KEP/%`"-WX).!$1;B_H$8&
MF7!$0D;]]_KN#?4`0+@P`VA#1`-@0"M_]"VN!IDX1LCK!`2(1/[W2_A3Y@WU
M`$!T,`)H`3(XYO_W9OD@1OWWMN\(D(KEVO@`4"7E1_90<PWU`4S/]O]S0*RP
M/%SX`P`#>%NQ_O=H_ABQ_?>@[P`H6]%4^`0/`W@`*_/13$^LY`?Q'`##\4`"
MP!@`(?WW..XX1O[W%?@-]0!)#?4`3`WU`$X-]0!`#?4`00WU`$(-]0!*#/&L
M#`[Q>`Y\,(`QA#()\8@)"O&,"@`CS/@`,`WU`$S.^``P#?4`3@-@#?4`0`M@
M#?4`01-@#?4`0LGX`#`-]0!)RO@`,`WU`$H,\9`,#O&4#I@PG#&@,@GQI`D*
M\:@*S/@`,,[X`#`#8`M@$V#)^``PRO@`,"+F!T9$Y*MX02M_]$JMZWA#*W_T
M1JTK>4@K?_1"K6MY12M_]#ZM;_`Y`D_P_S,'F,WX`(#]]Y;N!Y@I1BDB_?<"
M[LWX!+`"E0/G_?>8[@"_4,0``$C%````Q@``$,8``*#'```<Q@``^,4``,C$
M```$Q@``1,8``%3&```\Q@``+,8``"3&``!HQ@``+>GP1P`@_??R[@!H_??:
M[?WWY.T!(@-&J$@:</[WLOT8L0-X,2L`\,2`__?M^``@_??<[@!H_??&[:%)
M`2(+(_WW?NT`*`#PQH">3L)H5OCL/-+X&(`!*T#SZH``)0$D"N`X1OWWX.X`
M*##15OCL/`$T`36C0BS=`"#]][CN`&C]]Z#M048J1@`C_??V[8)&Z+$#:%;X
M\"S3^`B04O@D<!GT@&D8O]EHV]%(1OWWGNX`:/WWB.W:^``02D8"(_WWS.X!
M1CA&_?>P[@`HSM!6^.P\6AZJ0@#PBX``(/WWANX`:/WW<.UX20$B!2/]]RCM
M!$:`L0`@_?=Z[@!H_?=B[>-H<DH9:/WW*.WC:!MHFV@3](`/8=$`(/WW:.X`
M:/WW4NUK20$B!2/]]PKM!$:`L6A(_O<G_05&`"ALT``@_?=6[@!H_?<^[>-H
M*D89:/WW!.T`(%M-!T;]]TCN`&C]]S+M_?<\[0-&.$8?</WW/NX`:/WW*.W]
M]U+N`T962!]@_O<`_4;XZ`P`*%/00/+M$?WWB.P"'AB_`2(#1A$H#+\`(@+P
M`0(2L;#Q_S]^T;WH\(=#>``K?_0XKP`@_?<6[@!H_?<`[3Y)`2(+(_WWN.P`
M*'_T.J\[3G_G`"#]]P;N`&C]]_#LXV@9:/WW<.V2YP$K?_=RKP$D`"`!-/WW
M]NT`:/WWX.Q!1OWWE.Q6^.P\HT+QW&'G_??J[0!H_??2[.)H5OCP/!%H&FC^
M]^?\D.<`)4[G5?CP#/_WI/I%^.@,XV@;:)UH%?2`91B_V&@+T2A&_??,[0!H
M_?>T[.%H*D8"(PEH_??X[5;X\!S]]WKLXVA6^/`L&V@6:)]H%_2`9QB_VF@%
M1@S1.$;]][#M`&C]]YCLX6@Z1@(C"6C]]]SM`D8.2#%&*T;]]TSM5?CP+`M(
M$6A5^.@L_?=$[2S%``!PQ@``A,(!`'C&``!\Q@``A,8``&S%``!(Q0``B,8`
M`+C&```0M0`@_?>`[0!H_?=J[$SR"'%)]G1"3/(D<\#R``'`\@`"P/(``_WW
M7NT0O0"U`""#L/WW:NT`:/WW4NS_]^#_`"#]]V+M`&C]]TKL3/(P<4SR=0),
M\@1CP/(``\#R``'`\@`"3_``#`"3S?@$P/WW8NP#L`"]`+\'2]_X(,`0M0_R
M``YS1!/K#`X,OW-&4_@,,/WWX.P0O23L``!8`0``<$<`ORWI\$??^#2@`*,&
M1II$#T:01@M-_?=L^PI+[1J:1*T0"=``)%KX)#`P1@$T.49"1IA'K$+VT[WH
M\(<`O_CK``#8_O__U/[__Q"U`+\0O0```0`"`$C'``"`QP``D,<``)C'``"@
MQP``J,<```3&``!\QP``7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("``````;,<``'3'``#\Q0``!,8``+S%``#`Q0``8,<``$S%``!HQP``!,8`
M`$S'``!4QP``!,8``%!!4E]#3$5!3@```"]P<F]C+W-E;&8O97AE```E<R\E
M<P```"]P<F]C+R5I+R5S`&5X90`E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27U1%35``````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7U!23T=.04U%`````%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"
M04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]
M```Q````+@```'!A<BT`````+64``"TM```E<R5S)7,E<P````!P87)L````
M`"YP87(`````)7,E<V-A8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M)74E
M<P```"5S)7-T96UP+25U+25U)7,`````4UE35$5-``!!4D=6`````!@```!P
M97)L`````#`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T
M:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A
M<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN
M"@```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``````O````55-%4@````!54T523D%-10``
M``!414U01$E2`%1-4`!#.EQ414U0`"]T;7``````.@```$Q$7TQ)0E)!4EE?
M4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%4
M2````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@
M<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I
M;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T
M96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C
M875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T
M<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N
M9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@
M("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D
M:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@
M86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@
M82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F
M:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@
M("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@
M;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O
M9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@
M("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@
M("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S
M>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@
M("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H
M97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@
M*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF
M(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A
M;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@
M("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@
M7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@
M7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@
M("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M
M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U
M+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE
M*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R
M8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@
M("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@
M("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[
M(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R
M(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.
M;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI
M>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S
M('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R
M97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U
M<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@
M97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP
M;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A
M<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP
M87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]
M('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T
M86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@
M('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@
M(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T
M:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T
M:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@
M86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL
M('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*
M("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@
M("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@
M('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O
M7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@
M("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@
M("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@
M/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*
M("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@
M("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@
M("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R
M+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA
M;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@
M("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@
M?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@
M("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/
M<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`]
M(%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO
M9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E
M871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@
M?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@
M("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@
M("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@
M("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D
M97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B
M=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@
M<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*
M("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@
M("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L
M:6U](&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@
M(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@
M("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U
M=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@
M5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O
M9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR
M;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI
M;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY
M("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I
M;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@
M9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@
M("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@
M("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@
M("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F
M:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M
M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO
M:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q
M<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E
M;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@
M)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D
M8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4[
M"@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO
M861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@
M("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ
M+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE
M*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C
M($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*
M("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@
M("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@
M("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L
M;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI
M=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE
M(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE
M(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@
M("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@
M("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI
M"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@
M("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@
M("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA
M:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC
M('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A
M=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI
M8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E
M<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*
M("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@
M<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!E=F%L('L@
M<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@
M("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*?0H*(R!4:&4@0R!V
M97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER
M+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A
M<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@
M<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@
M("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@
M("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*
M("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V
M97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I
M9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M
M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@
M("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@
M("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R
M96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O
M7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@
M("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@
M/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B
M(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY
M("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M
M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@
M("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@
M('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE
M;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F
M:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0
M<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q
M.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@
M("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R
M971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I
M>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O
M(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U
M8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@
M("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@
M("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@
M("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@
M;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@
M>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN
M8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G
M92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PH*,3L*"B-L:6YE(#$P,3(*"E]?14Y$7U\*````<&%R+G!L```X>_]_`0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!!GP``,9\````````!`````0``
M``$```"R`@```0```+T"```!````QP(```$````6`P```0```%L$```!````
M>P0```P```#MF@``#0```$7$```9````U*X!`!L````$````&@```-BN`0`<
M````!`````0```"L@0``]?[_;R2%```%````R)````8````8B0``"@```"0&
M```+````$````!4``````````P````"P`0`"````B`(``!0````1````%P``
M`&28```1````1)@``!(````@````$P````@```#^__]OY)<``/___V\#````
M\/__;^R6````````````````````````````````````````````````````
M``````````````#@K@$```````````#XF@``^)H``/B:``#XF@``^)H``/B:
M``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H`
M`/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``
M^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#X
MF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:
M``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H`
M`/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``#XF@``
M^)H``/B:``#XF@``^)H``/B:``#XF@``^)H``/B:``````````````````#_
M____F",!`-E;``!!+@```&%E86)I``$D````!3<M00`&"@=!"`$)`@H$$@04
M`14!%P,8`1D!&@(;`T=#0SH@*%5B=6YT=2`T+C0N,BTY=6)U;G1U-"D@-"XT
M+C,@,C`Q,#`Q,38@*'!R97)E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN
M97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"Y!4DTN871T<FEB=71E<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M```+`````0````(```!4@0``5`$``!,```````````````$`````````$P``
M``<````"````:($``&@!```@```````````````$`````````"$````'````
M`@```(B!``"(`0``)```````````````!``````````X````!0````(```"L
M@0``K`$``'@#```&``````````0````$````-````/;__V\"````)(4``"0%
M``#T`P``!@`````````$````!````#X````+`````@```!B)```8"0``L`<`
M``<````!````!````!````!&`````P````(```#(D```R!```"0&````````
M``````$`````````3@```/___V\"````[)8``.P6``#V````!@`````````"
M`````@```%L```#^__]O`@```.27``#D%P``8`````<````#````!```````
M``!J````"0````(```!$F```1!@``"`````&``````````0````(````<P``
M``D````"````9)@``&08``"(`@``!@````T````$````"````'P````!````
M!@```.R:``#L&@``"@``````````````!`````````!W`````0````8```#X
MF@``^!H``.`#``````````````0````$````@@````$````&````V)X``-@>
M``!L)0`````````````(`````````(@````!````!@```$3$``!$1```!@``
M````````````!`````````".`````0````(```!,Q```3$0``%1?````````
M``````0`````````E@````$``'""````H",!`*"C```(````#@`````````$
M`````````*$````!`````@```*@C`0"HHP``!```````````````!```````
M``"K````#@````,```#4K@$`U*X```0```````````````0`````````MP``
M``\````#````V*X!`-BN```$```````````````$`````````,,````!````
M`P```-RN`0#<K@``!```````````````!`````````#(````!@````,```#@
MK@$`X*X``"`!```'``````````0````(````T0````$````#`````+`!``"P
M``!4`0`````````````$````!````-8````!`````P```%2Q`0!4L0``%```
M````````````!`````````#<````"`````,```!HL0$`:+$``#@0````````
M``````@`````````X0````,``'```````````&BQ```O```````````````!
M`````````/$````!````,`````````"7L0``.0```````````````0````$`
M```!`````P``````````````T+$``/H```````````````$``````````0``
M`/B:```````````-``0````(FP``````````#0`!````#)L```````````T`
'`"1A`"1D````
